#[repr(C)]pub struct SpiImplLockBusRequest {
pub chip_select: u32,
}Fields
chip_select: u32Trait Implementations
Sourceimpl Clone for SpiImplLockBusRequest
impl Clone for SpiImplLockBusRequest
Sourcefn clone(&self) -> SpiImplLockBusRequest
fn clone(&self) -> SpiImplLockBusRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SpiImplLockBusRequest
impl Debug for SpiImplLockBusRequest
Sourceimpl<'a, ___E> Encode<SpiImplLockBusRequest, ___E> for &'a SpiImplLockBusRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<SpiImplLockBusRequest, ___E> for &'a SpiImplLockBusRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SpiImplLockBusRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SpiImplLockBusRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<SpiImplLockBusRequest, ___E> for SpiImplLockBusRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<SpiImplLockBusRequest, ___E> for SpiImplLockBusRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, SpiImplLockBusRequest>
const COPY_OPTIMIZATION: CopyOptimization<Self, SpiImplLockBusRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SpiImplLockBusRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SpiImplLockBusRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, SpiImplLockBusRequest>, ___E> for &'a SpiImplLockBusRequest
impl<'a, ___E> EncodeOption<Box<'static, SpiImplLockBusRequest>, ___E> for &'a SpiImplLockBusRequest
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, SpiImplLockBusRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, SpiImplLockBusRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, SpiImplLockBusRequest>, ___E> for SpiImplLockBusRequest
impl<___E> EncodeOption<Box<'static, SpiImplLockBusRequest>, ___E> for SpiImplLockBusRequest
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, SpiImplLockBusRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, SpiImplLockBusRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<SpiImplLockBusRequest> for SpiImplLockBusRequest
impl FromWire<SpiImplLockBusRequest> for SpiImplLockBusRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<SpiImplLockBusRequest, Self>
const COPY_OPTIMIZATION: CopyOptimization<SpiImplLockBusRequest, Self>
Sourcefn from_wire(wire: SpiImplLockBusRequest) -> Self
fn from_wire(wire: SpiImplLockBusRequest) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<SpiImplLockBusRequest> for SpiImplLockBusRequest
impl FromWireRef<SpiImplLockBusRequest> for SpiImplLockBusRequest
Sourcefn from_wire_ref(wire: &SpiImplLockBusRequest) -> Self
fn from_wire_ref(wire: &SpiImplLockBusRequest) -> Self
Converts the given reference to this type.
Sourceimpl Hash for SpiImplLockBusRequest
impl Hash for SpiImplLockBusRequest
Sourceimpl Ord for SpiImplLockBusRequest
impl Ord for SpiImplLockBusRequest
Sourcefn cmp(&self, other: &SpiImplLockBusRequest) -> Ordering
fn cmp(&self, other: &SpiImplLockBusRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for SpiImplLockBusRequest
impl PartialEq for SpiImplLockBusRequest
Sourcefn eq(&self, other: &SpiImplLockBusRequest) -> bool
fn eq(&self, other: &SpiImplLockBusRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for SpiImplLockBusRequest
impl PartialOrd for SpiImplLockBusRequest
impl Copy for SpiImplLockBusRequest
impl Eq for SpiImplLockBusRequest
impl StructuralPartialEq for SpiImplLockBusRequest