pub struct SpiImplReceiveVmoRequest {
pub chip_select: u32,
pub buffer: SharedVmoBuffer,
}Fields
chip_select: u32buffer: SharedVmoBufferTrait Implementations
Sourceimpl Clone for SpiImplReceiveVmoRequest
impl Clone for SpiImplReceiveVmoRequest
Sourcefn clone(&self) -> SpiImplReceiveVmoRequest
fn clone(&self) -> SpiImplReceiveVmoRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SpiImplReceiveVmoRequest
impl Debug for SpiImplReceiveVmoRequest
Sourceimpl<'a, ___E> Encode<SpiImplReceiveVmoRequest, ___E> for &'a SpiImplReceiveVmoRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<SpiImplReceiveVmoRequest, ___E> for &'a SpiImplReceiveVmoRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SpiImplReceiveVmoRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SpiImplReceiveVmoRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<SpiImplReceiveVmoRequest, ___E> for SpiImplReceiveVmoRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<SpiImplReceiveVmoRequest, ___E> for SpiImplReceiveVmoRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SpiImplReceiveVmoRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SpiImplReceiveVmoRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, SpiImplReceiveVmoRequest>, ___E> for &'a SpiImplReceiveVmoRequest
impl<'a, ___E> EncodeOption<Box<'static, SpiImplReceiveVmoRequest>, ___E> for &'a SpiImplReceiveVmoRequest
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, SpiImplReceiveVmoRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, SpiImplReceiveVmoRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, SpiImplReceiveVmoRequest>, ___E> for SpiImplReceiveVmoRequest
impl<___E> EncodeOption<Box<'static, SpiImplReceiveVmoRequest>, ___E> for SpiImplReceiveVmoRequest
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, SpiImplReceiveVmoRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, SpiImplReceiveVmoRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<SpiImplReceiveVmoRequest> for SpiImplReceiveVmoRequest
impl FromWire<SpiImplReceiveVmoRequest> for SpiImplReceiveVmoRequest
Sourcefn from_wire(wire: SpiImplReceiveVmoRequest) -> Self
fn from_wire(wire: SpiImplReceiveVmoRequest) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<SpiImplReceiveVmoRequest> for SpiImplReceiveVmoRequest
impl FromWireRef<SpiImplReceiveVmoRequest> for SpiImplReceiveVmoRequest
Sourcefn from_wire_ref(wire: &SpiImplReceiveVmoRequest) -> Self
fn from_wire_ref(wire: &SpiImplReceiveVmoRequest) -> Self
Converts the given reference to this type.
Sourceimpl PartialEq for SpiImplReceiveVmoRequest
impl PartialEq for SpiImplReceiveVmoRequest
Sourcefn eq(&self, other: &SpiImplReceiveVmoRequest) -> bool
fn eq(&self, other: &SpiImplReceiveVmoRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for SpiImplReceiveVmoRequest