#[repr(C)]pub struct SpiImplLockBusRequest {
pub chip_select: Uint32,
}Expand description
The wire type corresponding to SpiImplLockBusRequest.
Fields
chip_select: Uint32Trait Implementations
Sourceimpl Clone for SpiImplLockBusRequest
impl Clone for SpiImplLockBusRequest
Sourcefn clone(&self) -> SpiImplLockBusRequest
fn clone(&self) -> SpiImplLockBusRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for SpiImplLockBusRequest
impl Constrained for SpiImplLockBusRequest
Sourceimpl Debug for SpiImplLockBusRequest
impl Debug for SpiImplLockBusRequest
Sourceimpl<___D> Decode<___D> for SpiImplLockBusRequestwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for SpiImplLockBusRequestwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<SpiImplLockBusRequest, ___E> for &'a SpiImplLockBusRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<SpiImplLockBusRequest, ___E> for &'a SpiImplLockBusRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SpiImplLockBusRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SpiImplLockBusRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<SpiImplLockBusRequest, ___E> for SpiImplLockBusRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<SpiImplLockBusRequest, ___E> for SpiImplLockBusRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, SpiImplLockBusRequest>
const COPY_OPTIMIZATION: CopyOptimization<Self, SpiImplLockBusRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SpiImplLockBusRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SpiImplLockBusRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<SpiImplLockBusRequest, ___E> for SpiImplLockBusRequest<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
impl<___E, T0> Encode<SpiImplLockBusRequest, ___E> for SpiImplLockBusRequest<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SpiImplLockBusRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SpiImplLockBusRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<SpiImplLockBusRequest> for SpiImplLockBusRequest
impl FromWire<SpiImplLockBusRequest> for SpiImplLockBusRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<SpiImplLockBusRequest, Self>
const COPY_OPTIMIZATION: CopyOptimization<SpiImplLockBusRequest, Self>
Sourcefn from_wire(wire: SpiImplLockBusRequest) -> Self
fn from_wire(wire: SpiImplLockBusRequest) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<SpiImplLockBusRequest> for SpiImplLockBusRequest
impl FromWireRef<SpiImplLockBusRequest> for SpiImplLockBusRequest
Sourcefn from_wire_ref(wire: &SpiImplLockBusRequest) -> Self
fn from_wire_ref(wire: &SpiImplLockBusRequest) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for SpiImplLockBusRequest
impl IntoNatural for SpiImplLockBusRequest
Sourcetype Natural = SpiImplLockBusRequest
type Natural = SpiImplLockBusRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for SpiImplLockBusRequest
impl Wire for SpiImplLockBusRequest
Sourcetype Narrowed<'de> = SpiImplLockBusRequest
type Narrowed<'de> = SpiImplLockBusRequest
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.