#[repr(C)]pub struct SpiImplReceiveVmoRequest {
pub chip_select: Uint32,
pub buffer: SharedVmoBuffer,
}Expand description
The wire type corresponding to SpiImplReceiveVmoRequest.
Fields
chip_select: Uint32buffer: SharedVmoBufferTrait Implementations
Sourceimpl Clone for SpiImplReceiveVmoRequest
impl Clone for SpiImplReceiveVmoRequest
Sourcefn clone(&self) -> SpiImplReceiveVmoRequest
fn clone(&self) -> SpiImplReceiveVmoRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for SpiImplReceiveVmoRequest
impl Constrained for SpiImplReceiveVmoRequest
Sourceimpl Debug for SpiImplReceiveVmoRequest
impl Debug for SpiImplReceiveVmoRequest
Sourceimpl<___D> Decode<___D> for SpiImplReceiveVmoRequestwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for SpiImplReceiveVmoRequestwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<SpiImplReceiveVmoRequest, ___E> for &'a SpiImplReceiveVmoRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<SpiImplReceiveVmoRequest, ___E> for &'a SpiImplReceiveVmoRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SpiImplReceiveVmoRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SpiImplReceiveVmoRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<SpiImplReceiveVmoRequest, ___E> for SpiImplReceiveVmoRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<SpiImplReceiveVmoRequest, ___E> for SpiImplReceiveVmoRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SpiImplReceiveVmoRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SpiImplReceiveVmoRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1> Encode<SpiImplReceiveVmoRequest, ___E> for SpiImplReceiveVmoRequest<T0, T1>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
T1: Encode<SharedVmoBuffer, ___E>,
impl<___E, T0, T1> Encode<SpiImplReceiveVmoRequest, ___E> for SpiImplReceiveVmoRequest<T0, T1>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
T1: Encode<SharedVmoBuffer, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SpiImplReceiveVmoRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SpiImplReceiveVmoRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<SpiImplReceiveVmoRequest> for SpiImplReceiveVmoRequest
impl FromWire<SpiImplReceiveVmoRequest> for SpiImplReceiveVmoRequest
Sourcefn from_wire(wire: SpiImplReceiveVmoRequest) -> Self
fn from_wire(wire: SpiImplReceiveVmoRequest) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<SpiImplReceiveVmoRequest> for SpiImplReceiveVmoRequest
impl FromWireRef<SpiImplReceiveVmoRequest> for SpiImplReceiveVmoRequest
Sourcefn from_wire_ref(wire: &SpiImplReceiveVmoRequest) -> Self
fn from_wire_ref(wire: &SpiImplReceiveVmoRequest) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for SpiImplReceiveVmoRequest
impl IntoNatural for SpiImplReceiveVmoRequest
Sourcetype Natural = SpiImplReceiveVmoRequest
type Natural = SpiImplReceiveVmoRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for SpiImplReceiveVmoRequest
impl Wire for SpiImplReceiveVmoRequest
Sourcetype Narrowed<'de> = SpiImplReceiveVmoRequest
type Narrowed<'de> = SpiImplReceiveVmoRequest
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.