#[repr(C)]pub struct SpiImplUnlockBusRequest {
pub chip_select: Uint32,
}Expand description
The wire type corresponding to SpiImplUnlockBusRequest.
Fields
chip_select: Uint32Trait Implementations
Sourceimpl Clone for SpiImplUnlockBusRequest
impl Clone for SpiImplUnlockBusRequest
Sourcefn clone(&self) -> SpiImplUnlockBusRequest
fn clone(&self) -> SpiImplUnlockBusRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for SpiImplUnlockBusRequest
impl Constrained for SpiImplUnlockBusRequest
Sourceimpl Debug for SpiImplUnlockBusRequest
impl Debug for SpiImplUnlockBusRequest
Sourceimpl<___D> Decode<___D> for SpiImplUnlockBusRequestwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for SpiImplUnlockBusRequestwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<SpiImplUnlockBusRequest, ___E> for &'a SpiImplUnlockBusRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<SpiImplUnlockBusRequest, ___E> for &'a SpiImplUnlockBusRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SpiImplUnlockBusRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SpiImplUnlockBusRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<SpiImplUnlockBusRequest, ___E> for SpiImplUnlockBusRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<SpiImplUnlockBusRequest, ___E> for SpiImplUnlockBusRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, SpiImplUnlockBusRequest>
const COPY_OPTIMIZATION: CopyOptimization<Self, SpiImplUnlockBusRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SpiImplUnlockBusRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SpiImplUnlockBusRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<SpiImplUnlockBusRequest, ___E> for SpiImplUnlockBusRequest<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
impl<___E, T0> Encode<SpiImplUnlockBusRequest, ___E> for SpiImplUnlockBusRequest<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SpiImplUnlockBusRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SpiImplUnlockBusRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<SpiImplUnlockBusRequest> for SpiImplUnlockBusRequest
impl FromWire<SpiImplUnlockBusRequest> for SpiImplUnlockBusRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<SpiImplUnlockBusRequest, Self>
const COPY_OPTIMIZATION: CopyOptimization<SpiImplUnlockBusRequest, Self>
Sourcefn from_wire(wire: SpiImplUnlockBusRequest) -> Self
fn from_wire(wire: SpiImplUnlockBusRequest) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<SpiImplUnlockBusRequest> for SpiImplUnlockBusRequest
impl FromWireRef<SpiImplUnlockBusRequest> for SpiImplUnlockBusRequest
Sourcefn from_wire_ref(wire: &SpiImplUnlockBusRequest) -> Self
fn from_wire_ref(wire: &SpiImplUnlockBusRequest) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for SpiImplUnlockBusRequest
impl IntoNatural for SpiImplUnlockBusRequest
Sourcetype Natural = SpiImplUnlockBusRequest
type Natural = SpiImplUnlockBusRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for SpiImplUnlockBusRequest
impl Wire for SpiImplUnlockBusRequest
Sourcetype Narrowed<'de> = SpiImplUnlockBusRequest
type Narrowed<'de> = SpiImplUnlockBusRequest
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.